[rtems commit] bsp/tqm8xx: Clear sbss section

Sebastian Huber sebh at rtems.org
Mon Sep 17 06:59:09 UTC 2018


Module:    rtems
Branch:    master
Commit:    94ea8a8b49167b4469b22f67e45dc330bf3ad474
Changeset: http://git.rtems.org/rtems/commit/?id=94ea8a8b49167b4469b22f67e45dc330bf3ad474

Author:    Sebastian Huber <sebastian.huber at embedded-brains.de>
Date:      Thu Sep 13 11:34:23 2018 +0200

bsp/tqm8xx: Clear sbss section

---

 bsps/powerpc/tqm8xx/start/start.S | 11 +++++++----
 1 file changed, 7 insertions(+), 4 deletions(-)

diff --git a/bsps/powerpc/tqm8xx/start/start.S b/bsps/powerpc/tqm8xx/start/start.S
index b16b92e..62e8c5b 100644
--- a/bsps/powerpc/tqm8xx/start/start.S
+++ b/bsps/powerpc/tqm8xx/start/start.S
@@ -107,11 +107,14 @@ copy_rest_of_text:
 start_code_in_ram:
 
 	/*
 	 * ROM/RAM startup: clear bss in SDRAM
 	 */
-	LA	r3, bsp_section_bss_begin  /* get start address of bss section */
-	LWI	r4, bsp_section_bss_size   /* get size of bss section */
-	bl	mpc8xx_zero_4          /* Clear the bss section */
+	LA	r3, bsp_section_sbss_begin
+	LWI	r4, bsp_section_sbss_size
+	bl	mpc8xx_zero_4
+	LA	r3, bsp_section_bss_begin
+	LWI	r4, bsp_section_bss_size
+	bl	mpc8xx_zero_4
 	/*
 	 * call boot_card
 	 */
@@ -107,11 +107,14 @@ copy_rest_of_text:
 
 	/*
-	 * ROM/RAM startup: clear bss in SDRAM
+	 * ROM/RAM startup: clear sbss/bss in SDRAM
 	 */



More information about the vc mailing list